summaryrefslogtreecommitdiffstats
path: root/kmymoney2/kmymoneyutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/kmymoneyutils.h')
-rw-r--r--kmymoney2/kmymoneyutils.h78
1 files changed, 39 insertions, 39 deletions
diff --git a/kmymoney2/kmymoneyutils.h b/kmymoney2/kmymoneyutils.h
index 8acb5c4..c6054e5 100644
--- a/kmymoney2/kmymoneyutils.h
+++ b/kmymoney2/kmymoneyutils.h
@@ -26,8 +26,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qcolor.h>
-#include <qfont.h>
+#include <tqcolor.h>
+#include <tqfont.h>
// ----------------------------------------------------------------------------
// KDE Headers
@@ -50,11 +50,11 @@ class KMyMoneyUtils
{
public:
/**
* This enum is used to describe the bits of an account type filter mask.
* Each bit is used to define a specific account class. Multiple classes
* can be specified by OR'ing multiple entries. The special entry @p last
* marks the left most bit in the mask and is used by scanners of this
* bitmask to determine the end of processing.
*/
enum categoryTypeE {
none = 0x00, ///< no account class selected
@@ -63,7 +63,7 @@ public:
expense = 0x04, ///< expense accounts selected
income = 0x08, ///< income accounts selected
equity = 0x10, ///< equity accounts selected
- last = 0x20 ///< the leftmost bit in the mask
+ last = 0x20 ///< the leftmost bit in the tqmask
};
enum transactionTypeE {
@@ -126,31 +126,31 @@ public:
*
* @param accountType numerical representation of the account type.
* For possible values, see MyMoneyAccount::accountTypeE
* @return QString representing the human readable form translated according to the language cataglogue
*
* @sa MyMoneyAccount::accountTypeToString()
*/
- static const QString accountTypeToString(const MyMoneyAccount::accountTypeE accountType);
+ static const TQString accountTypeToString(const MyMoneyAccount::accountTypeE accountType);
/**
* This method is used to convert an account type from it's
* string form to the internal used numeric value.
*
* @param type reference to a QString containing the string to convert
* @return accountTypeE containing the internal used numeric value. For possible
* values see MyMoneyAccount::accountTypeE
*/
- static MyMoneyAccount::accountTypeE stringToAccountType(const QString& type);
+ static MyMoneyAccount::accountTypeE stringToAccountType(const TQString& type);
/**
* This method is used to convert a security type from it's
* string form to the internal used numeric value.
*
* @param txt reference to a QString containing the string to convert
* @return eSECURITYTYPE containing the internal used numeric value. For possible
* values see MyMoneySecurity::eSECURITYTYPE
*/
- static MyMoneySecurity::eSECURITYTYPE stringToSecurity(const QString& txt);
+ static MyMoneySecurity::eSECURITYTYPE stringToSecurity(const TQString& txt);
/**
* This method is used to convert the internal representation of
@@ -158,11 +158,11 @@ public:
*
* @param securityType enumerated representation of the security type.
* For possible values, see MyMoneySecurity::eSECURITYTYPE
* @return QString representing the human readable form translated according to the language cataglogue
*
* @sa MyMoneySecurity::securityTypeToString()
*/
- static const QString securityTypeToString(const MyMoneySecurity::eSECURITYTYPE securityType);
+ static const TQString securityTypeToString(const MyMoneySecurity::eSECURITYTYPE securityType);
/**
* This method is used to convert the occurence type from it's
@@ -171,13 +171,13 @@ public:
* @param occurence numerical representation of the MyMoneySchedule
* occurence type
*
* @return QString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::occurenceToString()
*
* @deprecated Use i18n(MyMoneySchedule::occurenceToString(occurence)) instead
*/
- static const QString occurenceToString(const MyMoneySchedule::occurenceE occurence);
+ static const TQString occurenceToString(const MyMoneySchedule::occurenceE occurence);
/**
* This method is used to convert the payment type from it's
@@ -186,11 +186,11 @@ public:
* @param paymentType numerical representation of the MyMoneySchedule
* payment type
*
* @return QString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::paymentMethodToString()
*/
- static const QString paymentMethodToString(MyMoneySchedule::paymentTypeE paymentType);
+ static const TQString paymentMethodToString(MyMoneySchedule::paymentTypeE paymentType);
/**
* This method is used to convert the schedule weekend option from it's
@@ -199,11 +199,11 @@ public:
* @param weekendOption numerical representation of the MyMoneySchedule
* weekend option
*
* @return QString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::weekendOptionToString()
*/
- static const QString weekendOptionToString(MyMoneySchedule::weekendOptionE weekendOption);
+ static const TQString weekendOptionToString(MyMoneySchedule::weekendOptionE weekendOption);
/**
* This method is used to convert the schedule type from it's
@@ -212,11 +212,11 @@ public:
* @param type numerical representation of the MyMoneySchedule
* schedule type
*
* @return QString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::scheduleTypeToString()
*/
- static const QString scheduleTypeToString(MyMoneySchedule::typeE type);
+ static const TQString scheduleTypeToString(MyMoneySchedule::typeE type);
/**
* This method is used to convert a numeric index of an item
@@ -224,20 +224,20 @@ public:
*
* @param idx numeric index of item
*
* @return QString with text of this item
*/
- static const QString homePageItemToString(const int idx);
+ static const TQString homePageItemToString(const int idx);
/**
* This method is used to convert the name of a home page item
* to it's internal numerical representation
*
* @param txt QString reference of the items name
*
* @retval 0 @p txt is unknown
* @retval >0 numeric value for @p txt
*/
- static int stringToHomePageItem(const QString& txt);
+ static int stringToHomePageItem(const TQString& txt);
/**
* Retrieve a KDE KGuiItem for the new schedule button.
@@ -264,12 +264,12 @@ public:
* @retval true if @p name was changed
* @retval false if @p name remained unchanged
*/
- static bool appendCorrectFileExt(QString& name, const QString& extension);
+ static bool appendCorrectFileExt(TQString& name, const TQString& extension);
- static QPixmap billScheduleIcon(int size);
- static QPixmap depositScheduleIcon(int size);
- static QPixmap transferScheduleIcon(int size);
- static QPixmap scheduleIcon(int size);
+ static TQPixmap billScheduleIcon(int size);
+ static TQPixmap depositScheduleIcon(int size);
+ static TQPixmap transferScheduleIcon(int size);
+ static TQPixmap scheduleIcon(int size);
/**
* Check that internal MyMoney engine constants use the same
@@ -277,7 +277,7 @@ public:
*/
static void checkConstants(void);
- static QString variableCSS(void);
+ static TQString variableCSS(void);
/**
* This method searches a KDE specific resource and applies country and
@@ -298,7 +298,7 @@ public:
* @code
*
* :
* QString fname = KMyMoneyUtils::findResource("appdata", "html/home%1.html")
* :
*
* @endcode
@@ -313,7 +313,7 @@ public:
*
* @note See KStandardDirs::findResource() for details on the parameters
*/
- static QString findResource(const char* type, const QString& filename);
+ static TQString findResource(const char* type, const TQString& filename);
/**
* This method returns the split referencing a stock account if
@@ -343,22 +343,22 @@ public:
*
* @param schedule const reference to the schedule the transaction is based on
* @param transaction reference to the transaction to be checked and modified
* @param balances QMap of (account-id,balance) pairs to be used as current balance
* for the calculation of interest. If map is empty, the engine
* will be interrogated for current balances.
*/
- static void calculateAutoLoan(const MyMoneySchedule& schedule, MyMoneyTransaction& transaction, const QMap<QString, MyMoneyMoney>& balances);
+ static void calculateAutoLoan(const MyMoneySchedule& schedule, MyMoneyTransaction& transaction, const TQMap<TQString, MyMoneyMoney>& balances);
/**
* Return next check number for account @a acc.
*/
- static QString nextCheckNumber(const MyMoneyAccount& acc);
+ static TQString nextCheckNumber(const MyMoneyAccount& acc);
/**
* Returns the text representing the reconcile flag. If @a text is @p true
* then the full text will be returned otherwise a short form (usually one character).
*/
- static QString reconcileStateToString(MyMoneySplit::reconcileFlagE flag, bool text = false);
+ static TQString reconcileStateToString(MyMoneySplit::reconcileFlagE flag, bool text = false);
/**
* Returns the transaction for @a schedule. In case of a loan payment the
@@ -375,7 +375,7 @@ public:
* ids of those categories in @a feesId and @a interestId. The last used category
* will be returned.
*/
- static void previouslyUsedCategories(const QString& investmentAccount, QString& feesId, QString& interestId);
+ static void previouslyUsedCategories(const TQString& investmentAccount, TQString& feesId, TQString& interestId);
};
@@ -50,11 +50,11 @@ class KMyMoneyUtils
public:
/**
- * This enum is used to describe the bits of an account type filter mask.
+ * This enum is used to describe the bits of an account type filter tqmask.
* Each bit is used to define a specific account class. Multiple classes
* can be specified by OR'ing multiple entries. The special entry @p last
@@ -50,11 +50,11 @@ class KMyMoneyUtils
* Each bit is used to define a specific account class. Multiple classes
* can be specified by OR'ing multiple entries. The special entry @p last
- * marks the left most bit in the mask and is used by scanners of this
- * bitmask to determine the end of processing.
+ * marks the left most bit in the tqmask and is used by scanners of this
+ * bittqmask to determine the end of processing.
*/
enum categoryTypeE {
@@ -126,31 +126,31 @@ public:
* @param accountType numerical representation of the account type.
* For possible values, see MyMoneyAccount::accountTypeE
- * @return QString representing the human readable form translated according to the language cataglogue
+ * @return TQString representing the human readable form translated according to the language cataglogue
*
* @sa MyMoneyAccount::accountTypeToString()
@@ -126,31 +126,31 @@ public:
* string form to the internal used numeric value.
*
- * @param type reference to a QString containing the string to convert
+ * @param type reference to a TQString containing the string to convert
* @return accountTypeE containing the internal used numeric value. For possible
* values see MyMoneyAccount::accountTypeE
@@ -126,31 +126,31 @@ public:
* string form to the internal used numeric value.
*
- * @param txt reference to a QString containing the string to convert
+ * @param txt reference to a TQString containing the string to convert
* @return eSECURITYTYPE containing the internal used numeric value. For possible
* values see MyMoneySecurity::eSECURITYTYPE
@@ -158,11 +158,11 @@ public:
* @param securityType enumerated representation of the security type.
* For possible values, see MyMoneySecurity::eSECURITYTYPE
- * @return QString representing the human readable form translated according to the language cataglogue
+ * @return TQString representing the human readable form translated according to the language cataglogue
*
* @sa MyMoneySecurity::securityTypeToString()
@@ -171,13 +171,13 @@ public:
* occurence type
*
- * @return QString representing the human readable format translated according to the language cataglogue
+ * @return TQString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::occurenceToString()
@@ -186,11 +186,11 @@ public:
* payment type
*
- * @return QString representing the human readable format translated according to the language cataglogue
+ * @return TQString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::paymentMethodToString()
@@ -199,11 +199,11 @@ public:
* weekend option
*
- * @return QString representing the human readable format translated according to the language cataglogue
+ * @return TQString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::weekendOptionToString()
@@ -212,11 +212,11 @@ public:
* schedule type
*
- * @return QString representing the human readable format translated according to the language cataglogue
+ * @return TQString representing the human readable format translated according to the language cataglogue
*
* @sa MyMoneySchedule::scheduleTypeToString()
@@ -224,20 +224,20 @@ public:
* @param idx numeric index of item
*
- * @return QString with text of this item
+ * @return TQString with text of this item
*/
@@ -224,20 +224,20 @@ public:
* to it's internal numerical representation
*
- * @param txt QString reference of the items name
+ * @param txt TQString reference of the items name
*
* @retval 0 @p txt is unknown
@@ -298,7 +298,7 @@ public:
*
* :
- * QString fname = KMyMoneyUtils::findResource("appdata", "html/home%1.html")
+ * TQString fname = KMyMoneyUtils::findResource("appdata", "html/home%1.html")
* :
*
@@ -343,22 +343,22 @@ public:
* @param schedule const reference to the schedule the transaction is based on
* @param transaction reference to the transaction to be checked and modified
- * @param balances QMap of (account-id,balance) pairs to be used as current balance
+ * @param balances TQMap of (account-id,balance) pairs to be used as current balance
* for the calculation of interest. If map is empty, the engine
* will be interrogated for current balances.